ServiceClient class

A low-level mechanism to communicate with Google APIs.

Constructors

ServiceClient({required Client client, String? gapicVersion, String? gcclVersion})
Creates a ServiceClient using client for transport.

Properties

client → Client
final
clientHeader String
The x-goog-api-client header value sent with every request.
no setter
gapicVersion String?
The version of the GAPIC-generated client library (e.g. 0.1.0), which will be formatted as gapic/<version> in the x-goog-api-client header.
final
gcclVersion String?
The version of the hand-written client library (e.g. 0.6.4), which will be formatted as gccl/<version> in the x-goog-api-client header.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
delete(Uri url) Future<Map<String, dynamic>>
deleteStreaming(Uri url, {required bool enableSse}) Stream<Map<String, dynamic>>
get(Uri url) Future<Map<String, dynamic>>
getStreaming(Uri url, {required bool enableSse}) Stream<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Uri url, {JsonEncodable? body}) Future<Map<String, dynamic>>
patchStreaming(Uri url, {required bool enableSse, JsonEncodable? body}) Stream<Map<String, dynamic>>
post(Uri url, {JsonEncodable? body}) Future<Map<String, dynamic>>
postStreaming(Uri url, {required bool enableSse, JsonEncodable? body}) Stream<Map<String, dynamic>>
put(Uri url, {JsonEncodable? body}) Future<Map<String, dynamic>>
putStreaming(Uri url, {required bool enableSse, JsonEncodable? body}) Stream<Map<String, dynamic>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited